@@ -42,6 +42,7 @@
 #include <QApt/Backend>
 #include <QApt/Config>
 #include <QApt/Changelog>
+#include <qapt/qaptversion.h>
 
 #include <MuonDataSources.h>
 
@@ -179,14 +180,14 @@ QString Application::menuPath()
     }
 
     if (!ret.isEmpty()) {
-        path.append(QString("<img width=\"16\" heigh=\"16\"src=\"%1\"/>")
+        path.append(QStringLiteral("<img width=\"16\" height=\"16\"src=\"%1\"/>")
                     .arg(KIconLoader::global()->iconPath("kde", KIconLoader::Small)));
-        path.append(QString("&nbsp;%1 <img width=\"16\" heigh=\"16\" src=\"%2\"/>&nbsp;%3")
+        path.append(QStringLiteral("&nbsp;%1 <img width=\"16\" height=\"16\" src=\"%2\"/>&nbsp;%3")
                     .arg(arrow)
                     .arg(KIconLoader::global()->iconPath("applications-other", KIconLoader::Small))
                     .arg(i18n("Applications")));
         for (int i = 0; i < ret.size(); i++) {
-            path.append(QString("&nbsp;%1&nbsp;<img width=\"16\" heigh=\"16\" src=\"%2\"/>&nbsp;%3")
+            path.append(QStringLiteral("&nbsp;%1&nbsp;<img width=\"16\" height=\"16\" src=\"%2\"/>&nbsp;%3")
                         .arg(arrow)
                         .arg(KIconLoader::global()->iconPath(ret.at(i).second, KIconLoader::Small))
                         .arg(ret.at(i).first));
@@ -446,6 +447,11 @@ void Application::clearPackage()
 QVector<KService::Ptr> Application::findExecutables() const
 {
     QVector<KService::Ptr> ret;
+    if (!m_package) {
+        qWarning() << "trying to find the executables for an uninitialized package!" << packageName();
+        return ret;
+    }
+
     foreach (const QString &desktop, m_package->installedFilesList().filter(QRegExp(".+\\.desktop$", Qt::CaseSensitive))) {
         // Important to use serviceByStorageId to ensure we get a service even
         // if the KSycoca database doesn't have our .desktop file yet.
@@ -488,13 +494,22 @@ AbstractResource::State Application::state()
     if (!package())
         return Broken;
 
-    State ret = None;
-
     int s = package()->state();
-    if(s & QApt::Package::Upgradeable) ret = Upgradeable;
-    else if(s & QApt::Package::Installed) ret = Installed;
+
+    if (s & QApt::Package::Upgradeable) {
+#if QAPT_VERSION >= QT_VERSION_CHECK(3, 1, 0)
+        if (package()->isInUpdatePhase())
+            return Upgradeable;
+#else
+        return Upgradeable;
+#endif
+    }
+
+    if (s & QApt::Package::Installed) {
+        return Installed;
+    }
     
-    return ret;
+    return None; // Actually: none of interest to us here in muon-discover.
 }
 
 void Application::fetchScreenshots()
@@ -587,7 +602,7 @@ void Application::processChangelog(KJob* j)
         if (m_package->origin() == QLatin1String("Ubuntu")) {
             changelog = i18nc("@info/rich", "The list of changes is not yet available. "
                                             "Please use <link url='%1'>Launchpad</link> instead.",
-                                            QString("http://launchpad.net/ubuntu/+source/" + m_package->sourcePackage()));
+                                            QStringLiteral("http://launchpad.net/ubuntu/+source/") + m_package->sourcePackage());
         } else {
             changelog = i18nc("@info", "The list of changes is not yet available.");
         }
